@@ -1,6 +1,8 @@
 package Alt::CWB::ambs;
 
-our $VERSION = '2.2.102.4';
+use warnings;
+use strict;
+our $VERSION = '2.2.102.5';
 
 1;
 
